==> manage-3.1.0-43.jar: management/sqls/sale/report/aode/YearByUserType.sql <==

select
		f_operate_date f_operate_date,  --日期
		SUM (CASE  WHEN f_gasproperties='民用用气' AND f_type='发卡售气' THEN 1 ELSE 0 END) f_open_my,  --民用次数
		SUM (CASE f_gasproperties WHEN '民用用气' THEN 1 ELSE 0 END) f_count_my,  --民用次数
		SUM (CASE f_gasproperties WHEN '民用用气' THEN f_pregas ELSE 0 END) f_pregas_my, --民用气量
		SUM (CASE f_gasproperties WHEN '民用用气' THEN f_collection ELSE 0 END) f_collection_my, --民用金额
		SUM (CASE  WHEN f_gasproperties='商业用气' AND f_type='发卡售气' THEN 1 ELSE 0 END) f_open_sy,  --商业次数
		SUM (CASE f_gasproperties WHEN '商业用气' THEN 1 ELSE 0 END) f_count_sy,  --民用次数
		SUM (CASE f_gasproperties WHEN '商业用气' THEN f_pregas ELSE 0 END) f_pregas_sy,  --商业气量
		SUM (CASE f_gasproperties WHEN '商业用气' THEN f_collection ELSE 0 END) f_collection_sy,  --商业金额
		SUM (CASE  WHEN f_gasproperties='工业用气' AND f_type='发卡售气' THEN 1 ELSE 0 END) f_open_gy,  --工业次数
		SUM (CASE f_gasproperties WHEN '工业用气' THEN 1 ELSE 0 END) f_count_gy,    --工业次数
		SUM (CASE f_gasproperties WHEN '工业用气' THEN f_pregas ELSE 0 END) f_pregas_gy,   --工业气量
		SUM (CASE f_gasproperties WHEN '工业用气' THEN f_collection ELSE 0 END) f_collection_gy,  --工业金额
		SUM(CASE WHEN f_type='发卡售气' THEN 1 ELSE 0 END) f_open,    --总开户量
		SUM(1) f_count,    --总开户量
		SUM(f_pregas) f_pregas,   --总开户气量
		SUM(f_collection) f_collection  --总开户金额
 from (
	select
	left(convert(varchar,case when f_operator = '悦生活' then f_write_date else f_operate_date end,21),7) f_operate_date,
	f_type,
	f_zones,
	f_gasproperties,
	f_pregas,
	f_collection
	from
	t_sellinggas s
	where   f_state<>'无效' and isnull(f_write_card,'')<>'未写卡'
	and year(case when f_operator = '悦生活' then f_write_date else f_operate_date end)= '{YeadDate}'
    and {condition}
		union all
	SELECT
		left(convert(varchar,f_operate_date,21),7)  f_operate_date,
		'补卡' f_type,
		f_zones,
		f_gasproperties,
		0 f_pregas,
		f_cardfees f_collection
	FROM
		t_fillcard s
	where  f_state<>'无效'
	and year(f_operate_date)= '{YeadDate}'
	and {condition}
	union all
	SELECT
		left(convert(varchar,f_operate_date,21),7) f_operate_date,
		'换表' f_type,
		f_zones,
		f_gasproperties,
		0 f_pregas,
		f_changemeter_fee f_collection
	FROM
		t_changetables s
	where  f_state<>'无效'
	and year(f_operate_date)= '{YeadDate}'
	and {condition}
	union all
	SELECT
		left(convert(varchar,f_operate_date,21),7)f_operate_date,
		'补气'  f_type,
		f_zones,
		f_gasproperties,
		0  f_pregas,
		0  f_collection
	FROM
		t_fillgas s
	where f_state<>'无效'
	and year(f_operate_date)= '{YeadDate}'
	and {condition}
) xx group by f_operate_date
order by f_operate_date

==> manage-3.1.0-44.jar: management/sqls/sale/report/aode/YearByUserType.sql <==

select
		f_operate_date f_operate_date,  --日期
		SUM (CASE  WHEN f_gasproperties='民用用气' AND f_type='发卡售气' THEN 1 ELSE 0 END) f_open_my,  --民用次数
		SUM (CASE f_gasproperties WHEN '民用用气' THEN 1 ELSE 0 END) f_count_my,  --民用次数
		SUM (CASE f_gasproperties WHEN '民用用气' THEN f_pregas ELSE 0 END) f_pregas_my, --民用气量
		SUM (CASE f_gasproperties WHEN '民用用气' THEN f_collection ELSE 0 END) f_collection_my, --民用金额
		SUM (CASE  WHEN f_gasproperties='商业用气' AND f_type='发卡售气' THEN 1 ELSE 0 END) f_open_sy,  --商业次数
		SUM (CASE f_gasproperties WHEN '商业用气' THEN 1 ELSE 0 END) f_count_sy,  --民用次数
		SUM (CASE f_gasproperties WHEN '商业用气' THEN f_pregas ELSE 0 END) f_pregas_sy,  --商业气量
		SUM (CASE f_gasproperties WHEN '商业用气' THEN f_collection ELSE 0 END) f_collection_sy,  --商业金额
		SUM (CASE  WHEN f_gasproperties='工业用气' AND f_type='发卡售气' THEN 1 ELSE 0 END) f_open_gy,  --工业次数
		SUM (CASE f_gasproperties WHEN '工业用气' THEN 1 ELSE 0 END) f_count_gy,    --工业次数
		SUM (CASE f_gasproperties WHEN '工业用气' THEN f_pregas ELSE 0 END) f_pregas_gy,   --工业气量
		SUM (CASE f_gasproperties WHEN '工业用气' THEN f_collection ELSE 0 END) f_collection_gy,  --工业金额
		SUM(CASE WHEN f_type='发卡售气' THEN 1 ELSE 0 END) f_open,    --总开户量
		SUM(1) f_count,    --总开户量
		SUM(f_pregas) f_pregas,   --总开户气量
		SUM(f_collection) f_collection  --总开户金额
 from (
	select
	left(convert(varchar,case when f_operator = '悦生活' then f_write_date else f_operate_date end,21),7) f_operate_date,
	f_type,
	f_zones,
	f_gasproperties,
	f_pregas,
	f_collection
	from
	t_sellinggas s
	where   f_state<>'无效' and isnull(f_write_card,'')<>'未写卡'
	and year(case when f_operator = '悦生活' then f_write_date else f_operate_date end)= '{YeadDate}'
    and {condition}
		union all
	SELECT
		left(convert(varchar,f_operate_date,21),7)  f_operate_date,
		'补卡' f_type,
		f_zones,
		f_gasproperties,
		0 f_pregas,
		f_cardfees f_collection
	FROM
		t_fillcard s
	where  f_state<>'无效'
	and (year(f_operate_date)= '{YeadDate}' or (year(f_operate_date)>='{f_begin_operate_date}' and year(f_operate_date)>='{f_end_operate_date}') )
	and {condition}
	union all
	SELECT
		left(convert(varchar,f_operate_date,21),7) f_operate_date,
		'换表' f_type,
		f_zones,
		f_gasproperties,
		0 f_pregas,
		f_changemeter_fee f_collection
	FROM
		t_changetables s
	where  f_state<>'无效'
	and (year(f_operate_date)= '{YeadDate}' or (year(f_operate_date)>='{f_begin_operate_date}' and year(f_operate_date)>='{f_end_operate_date}') )
	and {condition}
	union all
	SELECT
		left(convert(varchar,f_operate_date,21),7)f_operate_date,
		'补气'  f_type,
		f_zones,
		f_gasproperties,
		0  f_pregas,
		0  f_collection
	FROM
		t_fillgas s
	where f_state<>'无效'
	and (year(f_operate_date)= '{YeadDate}' or (year(f_operate_date)>='{f_begin_operate_date}' and year(f_operate_date)>='{f_end_operate_date}') )
	and {condition}
) xx group by f_operate_date
order by f_operate_date
